var Article, fs, pad, path, slug, _ref;
fs = require('fs');
path = require('path');
_ref = require('./utils'), slug = _ref.slug, pad = _ref.pad;
module.exports = Article = (function() {
  Article.fromFile = function(file, encoding, callback) {
    file = Article.includePath() + '/' + file;
    return fs.readFile(file, encoding, function(err, data) {
      var article, date, fileMatch;
      if (err) {
        return callback(err);
      }
      fileMatch = path.basename(file).match(/^([0-9]{4}-[0-9]{2}-[0-9]{2})-(.*)\..*$/);
      if (!fileMatch) {
        return callback('Invalid filename format');
      }
      article = new Article(data);
      date = fileMatch[1].replace(/-/g, '/');
      article.meta('date', date);
      article.meta('slug', fileMatch[2]);
      return callback(null, article);
    });
  };
  function Article(data) {
    var match, meta;
    data = data.replace(/\r\n/g, "\n");
    meta = data.split(/\n\n/, 1).toString();
    this.body(data.substring(meta.length + 2));
    while (match = meta.match(/([a-z0-9]+)\:\s*(.*)\s*\n?/i)) {
      this.meta(match[1].toLowerCase(), match[2]);
      meta = meta.substring(match[0].length);
    }
  }
  Article._baseUrl = '';
  Article.baseUrl = function(baseUrl) {
    if (baseUrl == null) {
      baseUrl = null;
    }
    if (baseUrl) {
      return Article._baseUrl = baseUrl;
    } else {
      return Article._baseUrl;
    }
  };
  Article._includePath = '';
  Article.includePath = function(includePath) {
    if (includePath == null) {
      includePath = null;
    }
    if (arguments.length > 0) {
      return Article._includePath = includePath;
    } else {
      return Article._includePath;
    }
  };
  Article._extension = '.txt';
  Article.extension = function(extension) {
    if (extension == null) {
      extension = null;
    }
    if (arguments.length > 0) {
      return Article._extension = extension;
    } else {
      return Article._extension;
    }
  };
  Article.prototype._body = '';
  Article.prototype.body = function(body) {
    if (body == null) {
      body = null;
    }
    if (body) {
      return this._body = body;
    } else {
      return this._body;
    }
  };
  Article.prototype._meta = {};
  Article.prototype.meta = function(key, value) {
    if (key == null) {
      key = null;
    }
    if (value == null) {
      value = null;
    }
    if (value) {
      return this._meta[key] = value;
    } else if (key) {
      return this._meta[key];
    } else {
      return this._meta;
    }
  };
  Article.prototype.title = function() {
    return this.meta('title');
  };
  Article.prototype.date = function(raw) {
    var date, day, month, year, _ref;
    if (raw == null) {
      raw = false;
    }
    date = this.meta('date');
    if (raw) {
      return date;
    } else {
      _ref = date.split('/'), year = _ref[0], month = _ref[1], day = _ref[2];
      return new Date(Date.UTC(year, month - 1, day));
    }
  };
  Article.prototype.slug = function() {
    return this.meta('slug') || slug(this.title());
  };
  Article.prototype.permalink = function(relative) {
    var base, date;
    if (relative == null) {
      relative = false;
    }
    date = this.date();
    base = relative ? '' : Article.baseUrl();
    return base + '/' + [date.getUTCFullYear(), pad(date.getUTCMonth() + 1), pad(date.getUTCDate()), this.slug()].join('/');
  };
  return Article;
})();