var Article, Helpers, View, connect, controllers;
connect = require('connect');
Article = require('./article');
View = require('./view');
Helpers = require('./helpers');
controllers = {
  article: require('./articleController'),
  error: require('./errorController')
};
module.exports = function(root, configs) {
  var server;
  module.exports.setDefaultConfigs(root, configs);
  Article.includePath(configs.articlesDir);
  Article.extension(configs.articlesExt);
  Article.baseUrl(configs.baseUrl);
  View.includePath(configs.templatesDir);
  View.extension(configs.templatesExt);
  View.globals({
    configs: configs
  });
  server = connect.createServer();
  if (configs.env === 'dev') {
    server.use(connect.logger());
    server.use(connect.profiler());
    server.use(connect.responseTime());
  }
  if (configs.favicon) {
    server.use(connect.favicon(configs.favicon));
  }
  if (configs.staticDir) {
    server.use(connect.static(configs.staticDir));
  }
  server.use(connect.router(module.exports.controllers.article(configs)));
  if (configs.env === 'dev') {
    server.use(connect.errorHandler({
      stack: true,
      dump: true,
      message: true
    }));
  } else {
    server.use(connect.router(function(app) {
      return app.get(/.*/, function(req, res, next) {
        return next(new Error(404));
      });
    }));
    server.use(module.exports.controllers.error(configs));
    process.on('uncaughtException', function(err) {
      return process.stderr.write(err + "\n");
    });
  }
  return server.listen(configs.port, configs.host);
};
module.exports.setDefaultConfigs = function(root, configs) {
  var _ref, _ref10, _ref11, _ref12, _ref13, _ref14, _ref15, _ref2, _ref3, _ref4, _ref5, _ref6, _ref7, _ref8, _ref9;
  configs != null ? configs : configs = {};
  (_ref = configs.title) != null ? _ref : configs.title = 'untitled blog';
  (_ref2 = configs.description) != null ? _ref2 : configs.description = '';
  (_ref3 = configs.env) != null ? _ref3 : configs.env = 'production';
  (_ref4 = configs.templatesDir) != null ? _ref4 : configs.templatesDir = root + '/templates';
  (_ref5 = configs.articlesDir) != null ? _ref5 : configs.articlesDir = root + '/articles';
  (_ref6 = configs.host) != null ? _ref6 : configs.host = '127.0.0.1';
  (_ref7 = configs.port) != null ? _ref7 : configs.port = 8080;
  (_ref8 = configs.baseUrl) != null ? _ref8 : configs.baseUrl = 'http://' + configs.host + (parseInt(configs.port) !== 80 ? ':' + configs.port : '');
  (_ref9 = configs.encoding) != null ? _ref9 : configs.encoding = 'utf8';
  (_ref10 = configs.perPage) != null ? _ref10 : configs.perPage = 10;
  (_ref11 = configs.articlesExt) != null ? _ref11 : configs.articlesExt = '.txt';
  (_ref12 = configs.templatesExt) != null ? _ref12 : configs.templatesExt = '.haml';
  (_ref13 = configs.favicon) != null ? _ref13 : configs.favicon = false;
  (_ref14 = configs.staticDir) != null ? _ref14 : configs.staticDir = false;
  return (_ref15 = configs.rss) != null ? _ref15 : configs.rss = false;
};
module.exports.controllers = controllers;
module.exports.Helpers = Helpers;
module.exports.Article = Article;
module.exports.View = View;